diff src/ui_fileops.h @ 138:71e1ebee420e

replaced gchar* path with FileData *fd
author nadvornik
date Tue, 11 Sep 2007 20:06:29 +0000
parents b15d4c18168f
children f9611a6cf0e2
line wrap: on
line diff
--- a/src/ui_fileops.h	Thu Aug 23 20:45:59 2007 +0000
+++ b/src/ui_fileops.h	Tue Sep 11 20:06:29 2007 +0000
@@ -51,12 +51,14 @@
 gchar *get_current_dir(void);
 
 /* return True on success, it is up to you to free
  * the lists with path_list_free()
  */
 gint path_list(const gchar *path, GList **files, GList **dirs);
 gint path_list_lstat(const gchar *path, GList **files, GList **dirs);
-void path_list_free(GList *list);
-GList *path_list_copy(GList *list);
+void string_list_free(GList *list);
+#define path_list_free string_list_free
+GList *string_list_copy(GList *list);
+#define path_list_copy string_list_copy
 
 long checksum_simple(const gchar *path);
@@ -51,12 +51,14 @@
 
 /* return True on success, it is up to you to free
- * the lists with path_list_free()
+ * the lists with string_list_free()
  */
 gint path_list(const gchar *path, GList **files, GList **dirs);